@@ -15,6 +15,7 @@
  * Go to <https://www.r-project.org/Licenses> for a copies of the licenses.
  */
 
+#include <stdio.h>  // snprintf
 #include "fansi.h"
 
 /* GENERAL NOTES ON WRITING/ALLOCATING FUNCTONS
@@ -717,7 +718,7 @@ static char * color_token(
     // nocov start
     error(
       "Internal Error: exceeded color buffer (%d vs %d).",
-      buff_track - buff, CLR_BUFF_SIZE
+      (int) (buff_track - buff), CLR_BUFF_SIZE
     );
     // nocov end
   return buff;
